@@ -1,8 +1,9 @@
 package App::Timestamper;
-$App::Timestamper::VERSION = '0.0.4';
+$App::Timestamper::VERSION = '0.0.5';
 use strict;
 use warnings;
 
+use IO::Handle;
 use Getopt::Long 2.36 qw(GetOptionsFromArray);
 use Pod::Usage qw/pod2usage/;
 
@@ -62,6 +63,7 @@ sub run
     my ($self) = @_;
 
     local @ARGV = @{$self->{_argv}};
+    STDOUT->autoflush(1);
 
     App::Timestamper::Filter::TS->new->fh_filter(\*ARGV, sub {print $_[0];});
 
@@ -80,7 +82,7 @@ App::Timestamper - prefix lines with the timestamps of their arrivals.
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
